import 'package:flutter/material.dart';

/// Conversation window
///
/// Simple container for a conversation
///
/// @author Pierre Hubert

class ConversationWindowContainer extends StatelessWidget {
  final Widget title;
  final void Function() onClose;
  final void Function() onToggleCollpase;
  final bool isCollapsed;
  final Widget body;

  const ConversationWindowContainer({
    Key key,
    @required this.title,
    @required this.onClose,
    @required this.body,
    @required this.onToggleCollpase,
    @required this.isCollapsed,
  })  : assert(title != null),
        assert(onClose != null),
        assert(body != null),
        assert(onToggleCollpase != null),
        assert(isCollapsed != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Container(
        width: 300,
        height: !isCollapsed ? 400 : 40,
        child: Scaffold(
          appBar: AppBar(
            title: GestureDetector(child: title, onTap: onToggleCollpase),
            actions: <Widget>[
              IconButton(icon: Icon(Icons.close), onPressed: onClose),
            ],
          ),
          body: Visibility(
            child: body,
            visible: !isCollapsed,
            maintainState: true,
          ),
        ),
      ),
    );
  }
}
